@@ -1,9 +1,9 @@
+use v5.10;
+
 package Mac::PropertyList::WriteBinary;
 use strict;
 use warnings;
 
-use vars qw( $VERSION @EXPORT_OK );
-
 use Encode              ();
 use Mac::PropertyList   ();
 use Math::BigInt;
@@ -102,8 +102,8 @@ use constant {
     havePack64   => ( eval { pack('Q>', 1153202979583557643) eq "\x10\x01\0\0\0\0\0\x0B" } ? 1 : 0 ),
 };
 
-$VERSION = '1.413';
-@EXPORT_OK = qw( as_string );
+our $VERSION = '1.502';
+our @EXPORT_OK = qw( as_string );
 
 sub as_string {
     my($value) = @_;
@@ -454,7 +454,7 @@ sub _as_bplist_fragment { return "\x08"; }
 
 Wim Lewis, C<< <wiml@cpan.org> >>
 
-Copyright © 2012-2014 Wim Lewis. All rights reserved.
+Copyright © 2012-2021 Wim Lewis. All rights reserved.
 
 Tom Wyant added support for UID types.
 
